UrlType class

Media type for URL references.

Extends FileTypeImpl to provide URL reference classification.

Inheritance
Available extensions

Constructors

UrlType()
Creates a UrlType.

Properties

extensionMap Map<String, String>
A map of file extensions to MIME types for this category.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
Properties used for equality comparison.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
value String
The category name of this file type.
finalinherited

Methods

fold<T>({required T orElse(), T image(ImageType image)?, T audio(AudioType audio)?, T video(VideoType video)?, T document(DocumentType doc)?, T url(UrlType url)?}) → T

Available on FileTypeImpl, provided by the MediaTypeExtension extension

Performs pattern matching on media types using a fold-like pattern.
isAny(List<FileType> list) bool
Checks if this file type matches any type in the provided list.
inherited
isAnyType(List<Type> list) bool
Checks if this file type's runtime type matches any type in the provided list.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited